
const parseArg  = require('minimist');
const objectTools = require('./object-tools.js');
const errorTools = require('./error-tools.js');
/**
 * console helper static tools class.
 *
 * contain parse process args
 */
class ConsoleTools{
  /**
   * parse process args
   * @param {Object} msg -input object
   * @propertyDetail {String[]} argv - process args
   * @propertyDetail {Object} [alias] -name is property name.alias name is property value,type is string or array
   * @propertyDetail {Object} [default] -default value. add to result when key not in process args
   * @returns {Object} result value after parse process args
   */
  static parseArgs(msg) {
    errorTools.validateJsonSchema({
      schema: schemas.parseArgs,
      data: msg,
    });
    if (!msg.default)
      msg.default = {};
    let args = parseArg(msg.argv.slice(2));
    if (msg.alias) {
      args = objectTools.alias({ obj: args, alias: msg.alias });
    }

    return objectTools.merge([args, msg.default]);
  }
}
const schemas = {
  parseArgs: {
    type: 'object',
    properties: {
      argv: {
        type: 'array',
      },
      alias: {
        type: 'object',
      },
      default: {
        type: 'object',
      },
    },
    required: ['argv'],
  },
};
module.exports = ConsoleTools;

