// © Copyright Mocoolka Corporation 2015,2017.
// Node module: mocoolka-tools
// LICENSE: MIT
const errorTools= require('./error-tools.js');
/**
 * format tools helper static class
 */
class FormatTools {
  /**
   * map format args to array by params in path that contain %s %d %j
   * @param {string} msg -param object
   * @propertyDetail {string} str- string that contain param
   * @propertyDetail {Array} args -will replace param
   * @returns {Array}
   */

  static mapArgs  (msg) {
    errorTools.validateJsonSchema
    ({ schema: schemas.mapArgs, data: msg });
    let path = msg.str;
    let args = msg.args;
    let ix = 1;
    let output = [];
    path.replace(/\%[sdj\%]/g, function (match) {
      if (match === '%%') return;
      let arg = args[ix++];
      if (arg === undefined) arg = 'undefined';
      if (arg === null) arg = 'null';
      output.push((match === '%j') ?
        JSON.stringify(arg) : arg.toString());
    });

    return output;
  };

  /**
   * %replace %s with {N} where N=0,1,2,...
   * @param {string}msg
   * @return {*|void|string|XML}
   */

  static mapPercent  (msg) {
    errorTools.validateJsonSchema
    ({ schema: schemas.mapPercent, data: msg });
    let ix = 0;
    return msg.replace(/\%[sdj\%]/g, function (match) {
      if (match === '%%') return '';
      let str = '{' + ix.toString() + '}';
      ix++;
      return str;
    });

  };

  /**
   * if %s %d %j is included in the string return true
   * @param {string}msg string checked
   * @return {boolean}
   */
  static retrievePercentSymbol  (msg) {
    errorTools.validateJsonSchema
    ({ schema: schemas.retrievePercentSymbol, data: msg });
   return /\%[sdj\%]/.test(msg);
  };
}

const schemas = {
  mapArgs: {
    type: 'object',
    properties: {
      str: {
        type: 'string',
      },
      args: {
        type: 'array',
      },
    },
    required: ['str', 'args'],
  },

  mapPercent: {
    type: 'string',
  },
  retrievePercentSymbol: {
    type: 'string',
  },

};
module.exports.__proto__ = FormatTools;
