// © Copyright Mocoolka Corporation 2015,2017.
// Node module: mocoolka-tools
// LICENSE: MIT

const  typeTools  = require('./type-tools.js');
const jsonSchemaTools = require('./validate/json-schema-tools');

/**
 * validate param or data
 */
class ValidateTools {
  /**
   * Determines whether the passed value is blank.
   * @param {*} obj -The object to be checked.
   * @return {boolean} -true if the object is an blank; otherwise, false.
   */

  static blank  (value) {
    if (typeTools.isEmpty(value)) return true;
    if (typeTools.isArray(value) && value.length === 0) return true;
    if (typeTools.isNumber(value) && isNaN(value)) return true;
    if (typeTools.isString(value) && value.trim() === '') return true;
    return false;
  };


  /**
   * Determines whether the passed message is correct
   * add type 'function'
   * @param {Object} msg -  The object to be checked.
   * @property {Object} msg.schema - json schema
   * @property {Object} msg.data - The data to be checked by schema
   * @callback callback function
   * @param {Error} error - null meaning pass
   */

  static validateJsonSchema  (msg, callback) {

    jsonSchemaTools.validate({ schema: schemas.validateJsonSchema, data: msg }, error=> {
      if (error)
        callback(error);
      else
       jsonSchemaTools.validate(msg, callback);
    });
  }
}
const schemas = {
  validateJsonSchema: {
    properties: {
      schema: {
        type: 'object',
      },
    },
    required: ['schema', 'data'],
  },
};
module.exports = ValidateTools;
